==> halloy-2024.12.tar.gz: halloy-2024.12/book/src/configuration/themes/community.md <==
# Community

This is a list of community created themes for Halloy.

> 💡 Have a great theme you want to share? Open a pull-request [here](https://github.com/squidowl/halloy/pulls).


## Oxocarbon 
 [Open in Halloy](halloy:///theme?e=ABYWFv8BJiYm_wImJib_A76V__8E8vT4_wVSUlL_Br6V__8HQr5l_wjuU5b_CT3b2f8KFhYW_wsfHh7_DBwcHP8NJiYm_w5jUIH_D76V__8QQDZP_xFCvmX_EjApOv8TOTk5_xRSUlL_FXip__8d_362_x4AAAAAHx0dHf8gJycn_yE2Njb_IiQkJP8jKCgo_yRANk__JVFDZ_8)

<img src="oxocarbon.png">

## Dracula 
 [Open in Halloy](halloy:///theme?e=ACgqNv8BHR8n_wJER1r_A2JypP8E-Pjy_wVyd5T_Br2T-v8HUPp7_wj_VVX_Cf-4bP8KHyIt_wsaGyT_DBobJP8NAAAAAA5Q-nv_D_95xv8QKy46_xH_ecb_EjU5R_8TkZKT_xTAwb__FYvp_f8d8fqM_x4oKjb_HygqNv8gPT1R_yExMUH_IisuOv8jMjZE_yQ7Nk7_JVZKcv8)

<img src="dracula.png">

## Gruvbox 
 [Open in Halloy](halloy:///theme?e=ACgoKP8BkoN0_wI8ODb_A7Fihv8E69uy_wWomYT_BrFihv8HmJca_wjMJB3_CdZdDv8KHSAh_wsoKCj_DB8hIf8NAAAAAA6Sg3T_D2idWv8QPDg2_xGOwHz_Ej05N_8TZlxU_xSSg3T_FUWFiP8d15kh_x4AAAAAHy4uLv8gMjIy_yE5OTn_IiImJ_8jJSor_yRBPDf_JVpSSv8)

<img src="gruvbox.png">

## Catppuccin Latte 
 [Open in Halloy](halloy:///theme?e=ANzg6P8BnKCw_wLM0Nr_A4g57_8ETE9p_wVsb4X_Bog57_8HQKAr_wjSDzn_Cf5kC_8K5unv_wvv8fX_DO_x9f8N3ODo_w7MuO__D3KH_f8Q1cnv_xEEpeX_ErXM9f8TnqG2_xSMj6H_FR5m9f8d344d_x4AAAAAH9bZ4f8gwcTK_yG3usD_IuPn7f8j1dne_yTUyO__JcKk7_8)

<img src="catppuccin-latte.png">


## Catppuccin Macchiato 
 [Open in Halloy](halloy:///theme?e=ABgZJv8BbnON_wIkJzr_A8ag9v8EytP1_wWlrcv_Bsag9v8HptqV_wjth5b_CfWpf_8KHiAw_wskJzr_DCQnOv8NGBkm_w5MQWP_D7e9-P8QWUx2_xGR1-P_EiwySv8TW2B2_xSAh6L_FYqt9P8d7tSf_x4AAAAAHx4fL_8gIiM1_yEnKD3_IiksQv8jMjVQ_yRKQGL_JY10sf8)

<img src="catppuccin-macchiato.png">

## Catppuccin Mocha 
 [Open in Halloy](halloy:///theme?e=ABERG_8BbHCG_wIeHi7_A8um9_8Ezdb0_wWmrcj_Bsum9_8HpuOh_wjzi6j_Cfqzh_8KGBgl_wseHi7_DB4eLv8NEREb_w5MQWP_D7e9-P8QWUx2_xGJ3Ov_EiwySv8TWFpu_xR_hJz_FYm0-v8d-eKv_x4AAAAAHxoaKf8gHh4v_yEiIjb_IiMjNv8jKytC_yRMQWP_JWhXhv8)

<img src="catppuccin-mocha.png">

## Ferra Light 
 [Open in Halloy](halloy:///theme?e=APTs5v8B3dDI_wLp2c7_A_-gev8EaFZQ_wWnmJH_BqNSxf8HdIYt_wjfUl7_CXSGLf8K8ebe_wvu4NX_DO_i2P8NAAAAAA7HubH_D6NSxf8Q9NbH_xHESGz_EubGw_8Trp2V_xSrinn_FWNg1v8dwZMX_x707Ob_H_Hl3f8g6trQ_yHm1cn_IunVyP8j38Kt_yTZ0bv_JcnFp_8)

<img src="ferra-light.png">

## Booberry 
 [Open in Halloy](halloy:///theme?e=AEUoWf8B27_v_wJUMm__Aza_hv8E2Mjz_wWtlr7_BuzNuv8HoPKP_wj0eGj_CejcoP8KOiJM_wsxHUH_DDYgR_8NAAAAAA6koOj_D8zMzP8QZFRv_xGg8o__ElBJbf8TgG2N_xTbv-__FYLOz_8d_80d_x4AAAAAH08uZf8gVDFs_yFWMm7_Ij8mU_8jRCla_ySFcpP_JcGo0_8)

<img src="booberry.png">

## One Dark
 [Open in Halloy](halloy:///theme?e=ACAkKv8Bc3Nz_wJgY2j_A_-MAP8Eu7u7_wWHjpv_BvRHR_8Hicp4_wjHVFD_CdVf3v8KKCw0_wsxN0H_DDE3Qf8NO0BI_w5gY2j_D4eOm_8QQlV7_xGJynj_EkBIWf8Tc3mE_xSHjpv_FWGv7_8dNZLE_x4AAAAAHzU6Rv8gREta_yFES1r_IiAkKv8jNTpG_yRES1r_JURLWv8)

<img src="one-dark.png">

## IntelliJ Light
 [Open in Halloy](halloy:///theme?e=AP____8Bv7-__wLg4OD_AwCN3v8ECAgI_wVBTUH_Bv8AAP8HsNGr_wjbWGD_CQBtzP8K_____wvw8PD_DPDw8P8N5ubm_w7g4OD_D0FNQf8QzMz__xEAjd7_EqbS__8TgICA_xRBTUH_FQBtzP8dOJ_W_x4AAAAAH9bW1v8g4ODg_yHg4OD_Iv____8j1tbW_yTg4OD_JeDg4P8)

<img src="intellij-light.png">

## Macaw Light
 [Open in Halloy](halloy:///theme?e=APHx8_8BtbW1_wLLzNf_AwB6__8EAAAA_wVsb4X_Bog57_8HlZWV_wiVlZX_CZWVlf8K_v___wvw8PD_DPDw8P8Nra2t_w6tra3_D3KH_f8Q1eD-_xFQbf__ErXM9f8TlZWV_xQAAAD_FR5m9f8dlZWV_x4AAAAAH-Li4v8g2tra_yHBwcH_Iu3t7f8j3t7e_yTs7Oz_Jenp6f8)

<img src="macaw-light.png">

## Macaw Dark
 [Open in Halloy](halloy:///theme?e=ADMzM_8BUFBQ_wIzMzP_AyiE_P8E39_f_wXCwsL_Bog57_8HlZWV_wiVlZX_CZWVlf8KHh4e_wsuLi7_DC4uLv8NGhoa_w4aGhr_D3KH_f8QRUZF_xEAyP__End3d_8TlZWV_xTf39__FSiE_P8dlZWV_x4AAAAAH0hISP8gSkpK_yFmZmb_Ijs7O_8jSEhI_yRkZGT_JWZmZv8)

<img src="macaw-dark.png">

==> halloy-2024.14.tar.gz: halloy-2024.14/book/src/configuration/themes/community.md <==
# Community

This is a list of community created themes for Halloy.

> 💡 Have a great theme you want to share? Open a pull-request [here](https://github.com/squidowl/halloy/pulls).


## Oxocarbon 
 [Open in Halloy](halloy:///theme?e=ABYWFv8BJiYm_wImJib_A76V__8E8vT4_wVSUlL_Br6V__8HQr5l_wjuU5b_CT3b2f8KFhYW_wsfHh7_DBwcHP8NJiYm_w5jUIH_D76V__8QQDZP_xFCvmX_EjApOv8TOTk5_xRSUlL_FXip__8d_362_x4AAAAAHx0dHf8gJycn_yE2Njb_IiQkJP8jKCgo_yRANk__JVFDZ_8)

<img src="oxocarbon.png">

## Dracula 
 [Open in Halloy](halloy:///theme?e=ACgqNv8BHR8n_wJER1r_A2JypP8E-Pjy_wVyd5T_Br2T-v8HUPp7_wj_VVX_Cf-4bP8KHyIt_wsaGyT_DBobJP8NAAAAAA5Q-nv_D_95xv8QKy46_xH_ecb_EjU5R_8TkZKT_xTAwb__FYvp_f8d8fqM_x4oKjb_HygqNv8gPT1R_yExMUH_IisuOv8jMjZE_yQ7Nk7_JVZKcv8)

<img src="dracula.png">

## Gruvbox 
 [Open in Halloy](halloy:///theme?e=ACgoKP8BkoN0_wI8ODb_A7Fihv8E69uy_wWomYT_BrFihv8HmJca_wjMJB3_CdZdDv8KHSAh_wsoKCj_DB8hIf8NAAAAAA6Sg3T_D2idWv8QPDg2_xGOwHz_Ej05N_8TZlxU_xSSg3T_FUWFiP8d15kh_x4AAAAAHy4uLv8gMjIy_yE5OTn_IiImJ_8jJSor_yRBPDf_JVpSSv8)

<img src="gruvbox.png">

## Catppuccin Latte 
 [Open in Halloy](halloy:///theme?e=ANzg6P8BnKCw_wLM0Nr_A4g57_8ETE9p_wVsb4X_Bog57_8HQKAr_wjSDzn_Cf5kC_8K5unv_wvv8fX_DO_x9f8N3ODo_w7MuO__D3KH_f8Q1cnv_xEEpeX_ErXM9f8TnqG2_xSMj6H_FR5m9f8d344d_x4AAAAAH9bZ4f8gwcTK_yG3usD_IuPn7f8j1dne_yTUyO__JcKk7_8)

<img src="catppuccin-latte.png">


## Catppuccin Macchiato 
 [Open in Halloy](halloy:///theme?e=ABgZJv8BbnON_wIkJzr_A8ag9v8EytP1_wWlrcv_Bsag9v8HptqV_wjth5b_CfWpf_8KHiAw_wskJzr_DCQnOv8NGBkm_w5MQWP_D7e9-P8QWUx2_xGR1-P_EiwySv8TW2B2_xSAh6L_FYqt9P8d7tSf_x4AAAAAHx4fL_8gIiM1_yEnKD3_IiksQv8jMjVQ_yRKQGL_JY10sf8)

<img src="catppuccin-macchiato.png">

## Catppuccin Mocha 
 [Open in Halloy](halloy:///theme?e=ABERG_8BbHCG_wIeHi7_A8um9_8Ezdb0_wWmrcj_Bsum9_8HpuOh_wjzi6j_Cfqzh_8KGBgl_wseHi7_DB4eLv8NEREb_w5MQWP_D7e9-P8QWUx2_xGJ3Ov_EiwySv8TWFpu_xR_hJz_FYm0-v8d-eKv_x4AAAAAHxoaKf8gHh4v_yEiIjb_IiMjNv8jKytC_yRMQWP_JWhXhv8)

<img src="catppuccin-mocha.png">

## Ferra Light 
 [Open in Halloy](halloy:///theme?e=APTs5v8B3dDI_wLp2c7_A_-gev8EaFZQ_wWnmJH_BqNSxf8HdIYt_wjfUl7_CXSGLf8K8ebe_wvu4NX_DO_i2P8NAAAAAA7HubH_D6NSxf8Q9NbH_xHESGz_EubGw_8Trp2V_xSrinn_FWNg1v8dwZMX_x707Ob_H_Hl3f8g6trQ_yHm1cn_IunVyP8j38Kt_yTZ0bv_JcnFp_8)

<img src="ferra-light.png">

## Booberry 
 [Open in Halloy](halloy:///theme?e=AEUoWf8B27_v_wJUMm__Aza_hv8E2Mjz_wWtlr7_BuzNuv8HoPKP_wj0eGj_CejcoP8KOiJM_wsxHUH_DDYgR_8NAAAAAA6koOj_D8zMzP8QZFRv_xGg8o__ElBJbf8TgG2N_xTbv-__FYLOz_8d_80d_x4AAAAAH08uZf8gVDFs_yFWMm7_Ij8mU_8jRCla_ySFcpP_JcGo0_8)

<img src="booberry.png">

## One Dark
 [Open in Halloy](halloy:///theme?e=ACAkKv8Bc3Nz_wJgY2j_A_-MAP8Eu7u7_wWHjpv_BvRHR_8Hicp4_wjHVFD_CdVf3v8KKCw0_wsxN0H_DDE3Qf8NO0BI_w5gY2j_D4eOm_8QQlV7_xGJynj_EkBIWf8Tc3mE_xSHjpv_FWGv7_8dNZLE_x4AAAAAHzU6Rv8gREta_yFES1r_IiAkKv8jNTpG_yRES1r_JURLWv8)

<img src="one-dark.png">

## IntelliJ Light
 [Open in Halloy](halloy:///theme?e=AP____8Bv7-__wLg4OD_AwCN3v8ECAgI_wVBTUH_Bv8AAP8HsNGr_wjbWGD_CQBtzP8K_____wvw8PD_DPDw8P8N5ubm_w7g4OD_D0FNQf8QzMz__xEAjd7_EqbS__8TgICA_xRBTUH_FQBtzP8dOJ_W_x4AAAAAH9bW1v8g4ODg_yHg4OD_Iv____8j1tbW_yTg4OD_JeDg4P8)

<img src="intellij-light.png">

## Macaw Light
 [Open in Halloy](halloy:///theme?e=APHx8_8BtbW1_wLLzNf_AwB6__8EAAAA_wVsb4X_Bog57_8HlZWV_wiVlZX_CZWVlf8K_v___wvw8PD_DPDw8P8Nra2t_w6tra3_D3KH_f8Q1eD-_xFQbf__ErXM9f8TlZWV_xQAAAD_FR5m9f8dlZWV_x4AAAAAH-Li4v8g2tra_yHBwcH_Iu3t7f8j3t7e_yTs7Oz_Jenp6f8)

<img src="macaw-light.png">

## Macaw Dark
 [Open in Halloy](halloy:///theme?e=ADMzM_8BUFBQ_wIzMzP_AyiE_P8E39_f_wXCwsL_Bog57_8HlZWV_wiVlZX_CZWVlf8KHh4e_wsuLi7_DC4uLv8NGhoa_w4aGhr_D3KH_f8QRUZF_xEAyP__End3d_8TlZWV_xTf39__FSiE_P8dlZWV_x4AAAAAH0hISP8gSkpK_yFmZmb_Ijs7O_8jSEhI_yRkZGT_JWZmZv8)

 <img src="macaw-dark.png">

## Zenburn
[Open in Halloy](halloy:///theme?e=ADg4OP8BrtYA_wJGRkb_A16urv8E3NzM_wWVlYr_BvDfr_8HX4cA_wjXXwD_Cf-4bP8KPz8__wsxMTH_DDExMf8NAAAAAA6u1gD_D_95xv8QPU9P_xH5nZj_EmFcT_8TYWFc_xTAwb__FYvp_f8dXq6u_x44ODj_Hy4uLv8gODg4_yEuLi7_Ij8_P_8jODg4_yQ4ODj_JTg4OP8)

<img src="zenburn.png">

## Solarized Dark
[Open in Halloy](halloy:///theme?e=AAArNv8Bk6Gh_wKToaH_A5Ohof8Eg5SW_wVYbnX_BpOhof8HhZkA_wjcMi__CctLFv8KACs2_wsHNkL_DAc2Qv8Ng5SW_w6ToaH_D9M2gv8QBzZC_xEmi9L_EgArNv8TWG51_xSDlJb_FSqhmP8dWG51_x4AKzb_Hwc2Qv8gBzZC_yEHNkL_IgArNv8jBzZC_yQHNkL_JQc2Qv8)

<img src="solarized-dark.png">
